using System;
using fomm.Scripting;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Text;
using System.Text.RegularExpressions;
using System.IO;
using System.Windows.Forms;
using System.Globalization;

// Marriable Serana - Version 1.6.2
// Includes v2 graphical installer scripting. (WIP)

class Script : SkyrimBaseScript
{
	const string title = "Marriable Serana";
	const string version = "1.6.2";
	
//	static ASCIIEncoding encoding;
	static Form installerForm;
	static PictureBox headerpicture;
	static Image headerimage;
	static TextBox textArea;
	static Button installButton;
	static Button cancelButton;
	
	static bool install = false;
	
	// Check and Install	

	public static bool OnActivate()
	{
//		encoding = new ASCIIEncoding();
		InitialiseComponents();
		installerForm.ShowDialog();

		if (install)
		{
			DoInstallation();
		}
		return install;
	}

	public static void DoInstallation()
	{
	// Recommended Unofficial Patches
	// bool SkyrimPatch = DataFileExists("Unofficial Skyrim Patch.esp");
	// bool DawnguardPatch = DataFileExists("Unofficial Dawnguard Patch.esp");
	// bool HearthfiresPatch = DataFileExists("Unoffical Hearthfire Patch.esp");
	
		InstallFileFromFomod("Marriable Serana.esp");
		InstallFileFromFomod("Marriable Serana.bsa");
		InstallFileFromFomod("Marriable Serana.bsl");
		SetPluginActivation("Marriable Serana.esp", true);
		
		if(DataFileExists("HearthFires.esm"))		// Install Hearthfires plugin if DLC exists.
		{
			InstallFileFromFomod("Hearthfires/Marriable Serana HF.esp", "Marriable Serana HF.esp");
			InstallFileFromFomod("Hearthfires/Marriable Serana HF.bsa", "Marriable Serana HF.bsa");
			InstallFileFromFomod("Hearthfires/Marriable Serana HF.bsl", "Marriable Serana HF.bsl");
			SetPluginActivation("Marriable Serana HF.esp", true);
		}
	}

	public static void InitialiseComponents()
    {
		headerimage = GetImageFromFomod("FOMod/MSeranaHeader.jpg");
		headerpicture = new System.Windows.Forms.PictureBox();
		textArea = new System.Windows.Forms.TextBox();
        installButton = new System.Windows.Forms.Button();
        cancelButton = new System.Windows.Forms.Button();
 
	// Header Image

		headerpicture.Image = headerimage;
		headerpicture.Location = new System.Drawing.Point(25, 12);
		headerpicture.Name = "headerpicture";
		headerpicture.Size = new System.Drawing.Size(450, 200);
		headerpicture.SizeMode = System.Windows.Forms.PictureBoxSizeMode.CenterImage;
		headerpicture.TabIndex = 0;
		headerpicture.TabStop = false;

	// Information Text Area

        textArea.BackColor = System.Drawing.Color.Black;
		textArea.ForeColor = System.Drawing.Color.Red;
        textArea.Location = new System.Drawing.Point(50, 225);
        textArea.Font = new System.Drawing.Font("Courier New", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
        textArea.Multiline = true;
        textArea.Name = "textArea";
        textArea.ReadOnly = true;
        textArea.ScrollBars = System.Windows.Forms.ScrollBars.Both;
		textArea.Size = new System.Drawing.Size(400, 220);
        textArea.TabIndex = 1;
		textArea.TabStop = false;

	// Install Button

		installButton.Location = new System.Drawing.Point(125, 457);
        installButton.Name = "installButton";
        installButton.Size = new System.Drawing.Size(75, 23);
        installButton.TabIndex = 2;
        installButton.Text = "Install";
        installButton.UseVisualStyleBackColor = true;
        installButton.Click += new System.EventHandler(installButton_Click);

	// Cancel Button

		cancelButton.Location = new System.Drawing.Point(300, 457);
        cancelButton.Name = "cancelButton";
        cancelButton.Size = new System.Drawing.Size(75, 23);
        cancelButton.TabIndex = 3;
        cancelButton.Text = "Cancel";
        cancelButton.UseVisualStyleBackColor = true;
        cancelButton.Click += new System.EventHandler(cancelButton_Click);

	// Installer Form

		installerForm = CreateCustomForm();
        installerForm.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
        installerForm.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
		installerForm.BackColor = System.Drawing.Color.Black;
		installerForm.ClientSize = new System.Drawing.Size(500, 492);
        installerForm.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
        installerForm.MaximizeBox = false;
		installerForm.MinimizeBox = false;
        installerForm.Controls.Add(installButton);
        installerForm.Controls.Add(cancelButton);
        installerForm.Controls.Add(textArea);
		installerForm.Controls.Add(headerpicture);
        installerForm.Name = "installerForm";
        installerForm.Text = "Marriable Serana";
        installerForm.Load += new System.EventHandler(installerForm_Load);
	}

	static void installButton_Click(object sender, EventArgs e)
	{
		install = true;
		installerForm.Close();
	}

	static void cancelButton_Click(object sender, EventArgs e)
	{
		install = false;
		installerForm.Close();
	}

	static void installerForm_Load(object sender, EventArgs e)
	{
		DLCDetection();
	}
	
	static void DLCDetection()
	{
		textArea.Clear();

		PrintReport("");
		PrintReport("Version " + version);
		PrintReport("");
		
		if (DataFileExists("Dawnguard.esm"))
		{
			PrintReport("Dawnguard Detected - YES");
		} else {
			PrintReport("Dawnguard Detected - NO");
			PrintReport("");
			PrintReport("Dawnguard DLC is required, installing without meeting this requirement will crash game.");
			PrintReport("");
		}

		if(DataFileExists("HearthFires.esm"))
		{
			PrintReport("Hearthfires Detected - YES");
			PrintReport("");
			PrintReport("Additional Hearthfires content will be installed.");
		} else {
			PrintReport("Hearthfires Detected - NO");
			PrintReport("");
			PrintReport("Hearthfires content will not be installed.");
		}
	}
	
	static void PrintReport(string line)
	{
		textArea.AppendText(line + "\n");
	}
	
	static Image GetImageFromFomod(string filename)
	{  
		byte[] data = GetFileFromFomod(filename);

		if (data == null)
			return null;

		MemoryStream stream = new MemoryStream(data);
		Image image = Image.FromStream(stream);
		stream.Close();        	
		return image;  
	}
}
